[svn.haxx.se] · SVN Dev · SVN Users · SVN Org · TSVN Dev · TSVN Users · Subclipse Dev · Subclipse Users · this month's index

[PATCH] Fix syntax inconsistency and update comments.

From: Noorul Islam K M <noorul_at_collab.net>
Date: Wed, 22 Dec 2010 11:57:29 +0530

Find attached minor patch which makes 'if' syntax consistent and also
some comment improvements.

Log

[[[

Fix syntax inconsistency and update comments.

* libsvn_client/locking_commands.c
  (organize_lock_targets): Fix syntax inconsistency. Update comments.

Patch by: Noorul Islam K M <noorul{_AT_}collab.net>
]]]

Thanks and Regards
Noorul

Index: libsvn_client/locking_commands.c
===================================================================
--- libsvn_client/locking_commands.c (revision 1051763)
+++ libsvn_client/locking_commands.c (working copy)
@@ -191,18 +191,15 @@
 
   /* Get the common parent and all paths */
   if (url_mode)
- {
       SVN_ERR(svn_uri_condense_targets(common_parent_url, &rel_targets,
                                        targets, TRUE, pool, pool));
- }
   else
- {
       SVN_ERR(svn_dirent_condense_targets(common_parent_url, &rel_targets,
                                           targets, TRUE, pool, pool));
- }
 
- /* svn_path_condense_targets leaves paths empty if TARGETS only had
- 1 member, so we special case that. */
+ /* svn_uri_condense_targets and svn_dirent_condense_targets leaves
+ URLs/paths empty if TARGETS only had 1 member, so we special case
+ that. */
   if (apr_is_empty_array(rel_targets))
     {
       const char *parent, *base;
@@ -273,8 +270,8 @@
       SVN_ERR(svn_uri_condense_targets(&common_url, &rel_urls, urls,
                                        FALSE, pool, pool));
 
- /* svn_path_condense_targets leaves paths empty if TARGETS only had
- 1 member, so we special case that (again). */
+ /* svn_uri_condense_targets leaves URLs empty if TARGETS only
+ had 1 member, so we special case that (again). */
       if (apr_is_empty_array(rel_urls))
         {
           const char *base_name = svn_uri_basename(common_url, pool);
Received on 2010-12-22 07:30:10 CET

This is an archived mail posted to the Subversion Dev mailing list.

This site is subject to the Apache Privacy Policy and the Apache Public Forum Archive Policy.